@@ -1,10 +1,11 @@
 from abc import ABC
 from GhostScan.CalibrationSession import CalibrationSession
 import os
+import cv2
 
 
 class IntrinsicCalibSession(CalibrationSession, ABC):
-    def __init__(self, camera, intrinsic_calib, path='CalibrationImages', no=5):
+    def __init__(self, camera, intrinsic_calib, path='CalibrationImages', no=20):
         # Set camera
         self.camera = camera
         self.path = path
@@ -15,12 +16,20 @@ class IntrinsicCalibSession(CalibrationSession, ABC):
         # For an intrinsic calibration you are required to image the same Aruco markers from different 20 viewing
         # positions changing in rotation and translation of the camera
         if not os.path.exists('CalibrationImages/Intrinsic/'):
+            if not os.path.exists('CalibrationImages'):
+                os.mkdir('CalibrationImages')
             os.mkdir('CalibrationImages/Intrinsic/')
         if not os.path.exists('CapturedImages/Intrinsic/'):
+            if not os.path.exists('CapturedImages'):
+                os.mkdir('CapturedImages')
             os.mkdir('CapturedImages/Intrinsic/')
         if not os.path.exists('CalibrationNumpyData/Intrinsic/'):
+            if not os.path.exists('CalibrationNumpyData'):
+                os.mkdir('CalibrationNumpyData')
             os.mkdir('CalibrationNumpyData/Intrinsic/')
         if not os.path.exists('CapturedNumpyData/Intrinsic/'):
+            if not os.path.exists('CalibrationNumpyData'):
+                os.mkdir('CalibrationNumpyData')
             os.mkdir('CapturedNumpyData/Intrinsic/')
             
         for i in range(self.no):
