@@ -22,12 +22,20 @@ class RadiometricCalibSession(CalibrationSession, ABC):
     def capture(self):
         # For radiometric calibration a series of differently exposed images of the same object is required
         if not os.path.exists('CalibrationImages/Radiometric/'):
+            if not os.path.exists('CalibrationImages'):
+                os.mkdir('CalibrationImages')
             os.mkdir('CalibrationImages/Radiometric/')
         if not os.path.exists('CapturedImages/Radiometric/'):
+            if not os.path.exists('CapturedImages'):
+                os.mkdir('CapturedImages')
             os.mkdir('CapturedImages/Radiometric/')
         if not os.path.exists('CalibrationNumpyData/Radiometric/'):
+            if not os.path.exists('CalibrationNumpyData'):
+                os.mkdir('CalibrationNumpyData')
             os.mkdir('CalibrationNumpyData/Radiometric/')
         if not os.path.exists('CapturedNumpyData/Radiometric/'):
+            if not os.path.exists('CalibrationNumpyData'):
+                os.mkdir('CalibrationNumpyData')
             os.mkdir('CapturedNumpyData/Radiometric/')
             
         for exp in self.exposures:
